Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorStéphane Bégaudeau2016-02-03 14:38:03 +0000
committerStéphane Bégaudeau2016-02-03 16:36:18 +0000
commitbf992caf36d25cecdb8ba57c39fc48aa5985790b (patch)
treef328703bdc3faa84f9b6e880a419b07a8fc4595c /tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal
parentcc576acb65d93eb7aece636fd0206e928b80f51a (diff)
downloadorg.eclipse.eef-bf992caf36d25cecdb8ba57c39fc48aa5985790b.tar.gz
org.eclipse.eef-bf992caf36d25cecdb8ba57c39fc48aa5985790b.tar.xz
org.eclipse.eef-bf992caf36d25cecdb8ba57c39fc48aa5985790b.zip
Add support for multiple groups in an IEEFSection.
1) An EEFSection is now initialized with an EEFPage 2) EEFGroups can now react to the various events available (aboutToBeShown, refresh, aboutToBeHidden, etc) Change-Id: I7f33936543b1b88b922fe92f509ef6fcc1629030 Signed-off-by: Stéphane Bégaudeau <stephane.begaudeau@obeo.fr>
Diffstat (limited to 'tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal')
-rw-r--r--tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal/controllers/EEFTextControllerTests.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal/controllers/EEFTextControllerTests.java b/tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal/controllers/EEFTextControllerTests.java
index addd75cb4..1076ef695 100644
--- a/tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal/controllers/EEFTextControllerTests.java
+++ b/tests/org.eclipse.eef.tests/src/org/eclipse/eef/tests/internal/controllers/EEFTextControllerTests.java
@@ -1,5 +1,5 @@
/*******************************************************************************
- * Copyright (c) 2015 Obeo.
+ * Copyright (c) 2015, 2016 Obeo.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
@@ -15,8 +15,8 @@ import java.util.Map;
import org.eclipse.eef.EEFTextDescription;
import org.eclipse.eef.EefFactory;
import org.eclipse.eef.core.api.EEFExpressionUtils;
-import org.eclipse.eef.core.api.controllers.EEFTextController;
-import org.eclipse.eef.core.internal.controllers.EEFTextControllerImpl;
+import org.eclipse.eef.core.api.controllers.IEEFTextController;
+import org.eclipse.eef.core.internal.controllers.EEFTextController;
import org.eclipse.emf.common.command.Command;
import org.eclipse.emf.common.command.CommandStack;
import org.eclipse.emf.common.notify.AdapterFactory;
@@ -40,7 +40,7 @@ import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.IsEqual.equalTo;
/**
* Unit tests for the {@link EEFTextController}.
*
* @author sbegaudeau
*/
@@ -71,7 +71,7 @@ public class EEFTextControllerTests {
AdapterFactory adapterFactory = new ComposedAdapterFactory(ComposedAdapterFactory.Descriptor.Registry.INSTANCE);
this.resourceSet = new ResourceSetImpl();
this.resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap()
- .put(Resource.Factory.Registry.DEFAULT_EXTENSION, new XMIResourceFactoryImpl());
+ .put(Resource.Factory.Registry.DEFAULT_EXTENSION, new XMIResourceFactoryImpl());
this.editingDomain = new TransactionalEditingDomainImpl(adapterFactory, this.resourceSet);
this.variableManager = new VariableManagerFactory().createVariableManager();
@@ -90,7 +90,7 @@ public class EEFTextControllerTests {
return EvaluationResult.of(newValue);
};
- EEFTextController controller = new EEFTextControllerImpl(description, variableManager, interpreter, editingDomain);
+ IEEFTextController controller = new EEFTextController(description, variableManager, interpreter, editingDomain);
controller.onNewValue((text) -> {
assertThat(text, equalTo(newValue));
});
@@ -127,7 +127,7 @@ public class EEFTextControllerTests {
return EvaluationResult.of(newLabel);
};
- EEFTextController controller = new EEFTextControllerImpl(description, variableManager, interpreter, editingDomain);
+ IEEFTextController controller = new EEFTextController(description, variableManager, interpreter, editingDomain);
controller.onNewLabel((label) -> {
assertThat(label, equalTo(newLabel));
});
@@ -40,7 +40,7 @@ import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.IsEqual.equalTo;
/**
- * Unit tests for the {@link EEFTextController}.
+ * Unit tests for the {@link IEEFTextController}.
*
* @author sbegaudeau

Back to the top